import os
import subprocess
import shlex
import glob
import shutil
import sys
sys.argv.append( '-b-' )
from ROOT import gROOT,gSystem,gDirectory
gSystem.Load("libSusyFitter.so")
from ROOT import ConfigMgr,FitConfig #this module comes from gSystem.Load("libSusyFitter.so")
gROOT.Reset()
from ROOT import TFile, RooWorkspace, TObject, TString, RooAbsReal, RooRealVar, RooFitResult, RooDataSet, RooAddition, RooArgSet,RooAbsData,RooRandom 
from ROOT import Util, TMath, RooStats
from ROOT import RooFit

import pickle


def fitresults(upLim,filename, f_output, workspacename='w', poiname='mu_SIG', mass_string='x_y',outdir='./'):
  
  #Retrieve workspace and check parameters are fine
  #=================================================
  w = Util.GetWorkspaceFromFile(filename,workspacename)
  
  if w==None:
    print "ERROR : Cannot open workspace : ", workspacename
    sys.exit(1) 

  modelConfig = w.obj("ModelConfig")
  poi = w.var(poiname)
  if poi==None:
    print "ERROR : Cannot find POI with name: ", poiname
    sys.exit(1)
  modelConfig.SetParametersOfInterest(RooArgSet(poi))

  print "Workspace description: "
  w.Print()


  #Calculate the limit
  #====================
  ntoys = 500
  calctype = 2   # toys = 0, asymptotic (asimov) = 2
  npoints = 20
  hti_result = RooStats.MakeUpperLimitPlot(poiname,w,calctype,3,ntoys,True,npoints)

  #Retrieve limit and store plot in directory
  #============================================
  outFileName = "./htiResult_poi_" + poiname + "_ntoys_" + str(ntoys) + "_npoints_" + str(npoints) + "_" + mass_string + ".root"
  hti_result.SaveAs(outFileName)
  hti_result.Print()
  shutil.move("upperlimit_cls_poi_mu_SIG_Asym_CLs_grid_ts3.root.eps",outdir+"/upperlimit_CLS_mu_SIG_" + mass_string + ".eps")
  #shutil.move("mu_SIG_Asym_CLs_grid_ts3.root",outdir)
  shutil.move(outFileName,outdir+"/"+outFileName)
  
  uL_nobsinSR = hti_result.UpperLimit()
  uL_nexpinSR = hti_result.GetExpectedUpperLimit(0)
  uL_nexpinSR_P = hti_result.GetExpectedUpperLimit(1) 
  uL_nexpinSR_M = hti_result.GetExpectedUpperLimit(-1)
  if uL_nexpinSR > uL_nexpinSR_P or uL_nexpinSR < uL_nexpinSR_M:
    print " \n something very strange, either the uL_nexpinSR > uL_nexpinSR_P or uL_nexpinSR < uL_nexpinSR_M"
    print "  uL_nexpinSR = ", uL_nexpinSR , " uL_nexpinSR_P = ", uL_nexpinSR_P, " uL_nexpinSR_M = ", uL_nexpinSR_M
  uL_nexpinSRerrP = hti_result.GetExpectedUpperLimit(1) - uL_nexpinSR
  uL_nexpinSRerrM = uL_nexpinSR - hti_result.GetExpectedUpperLimit(-1)

  f_output.write(str(uL_nobsinSR) + "\t" +  str(uL_nexpinSR) + "\n")
  print 'Result is:',uL_nobsinSR,uL_nexpinSR
  
  return 



############################## MAIN ####################################


usage = "This program calculates the upper limits for a selection of points in a grid. Needs the string to recognise the file (grid name and variables (if grid is \"ModelIndep\", the model independent upper limits are derived). Example: Gtt SR6T_1lepton_NT"

print "UpperLimit.py starting"

if len(sys.argv) < 3:
  print usage
  sys.exit(1)

grid = sys.argv[1]
analysis = sys.argv[2]


##Fixed parameters
workspacename = "combined"# 'w'    
poiname = 'mu_SIG'
outdir="out_"+grid+"_"+analysis
outfilename=outdir+"/UpperLimit_" + grid + "_" + analysis + ".txt"
##
print 'Will store limits in file:',outfilename


#Open output file name:
if not os.path.exists(outdir):
    os.makedirs(outdir)

f_upperlim = open(outfilename,"w")
f_upperlim.close()

if grid=="ModelIndep":
  filenameList = glob.glob("../../results/ModelIndep_" + analysis + "_SimpleChannel_SU_000_000_0_10_*combined*_BasicMeasurement_model.root")
  print "****Reading from: ../../results/ModelIndep_" + analysis + "_SimpleChannel_SU_000_000_0_10_*BasicMeasurement_model.root"
else:
  filenameList = glob.glob("../../results/" + grid + "_" + analysis + "_SimpleChannel_SU_*_*_0_10_*combined*_BasicMeasurement_model.root")
  print "****Reading from: ../../results/" + grid + "_" + analysis + "_SimpleChannel_SU_*_*_0_10_*combined*_BasicMeasurement_model.root"
  
for filename in filenameList:

  f_upperlim = open(outfilename,"a")
  
  print filename
  mass_string = (filename.split("SimpleChannel_SU_"))[1]
  mass_string = (mass_string.split("_0_10_"))[0]
  
  f_upperlim.write(mass_string + "\t" )
  upLim = {}
  fitresults(upLim,filename, f_upperlim, workspacename,poiname,mass_string,outdir)
  f_upperlim.close()

        
      
