#!/usr/bin/env python

import time, sys, commands, os, math
import ROOT
from ROOT import *
os.system("rm -rf Loader_C*")

ROOT.gROOT.ProcessLine('.L Loader.C+')

class BkgsData:
    def __init__(self):
        self.data   = -1
        self.SM   = -1
        self.SM_totuncert  = -1
        self.SM_sys  = -1
        self.SM_stat    = -1
        self.top    = -1
        self.top_uncert    = -1
        self.other    = -1
        self.other_uncert   = -1

class SignalPoint:
    def __init__(self):
        self.HistoName   = -1
        self.FinalPointName   = -1
        self.mgl  = -1
        self.mlsp  = -1
        self.nominal    = -1
        self.stats    = -1
        self.sys    = -1


def ReadFromFiles_BkgsData(filename):

    bd=BkgsData()
    file = open(filename)
    
    for line in file:
        linesp=line.split()
        if linesp[0]=="top":
            bd.top=float(linesp[1])
            bd.top_uncert=float(linesp[2])
        if linesp[0]=="other":
            bd.other=float(linesp[1])
            bd.other_uncert=float(linesp[2])
        if linesp[0]=="data":
            bd.data=float(linesp[1])

    bd.SM=bd.top+bd.other
    bd.SM_totuncert=math.sqrt(math.pow(bd.top_uncert,2)+math.pow(bd.other_uncert,2))
    return bd

def ReadFromFiles_Gtt(filename):

    Allsp=[]

    file = open(filename)
    for line in file:
        linesp=line.split()
        if linesp[0]!="mgl":
            sp=SignalPoint()
            sp.mgl=linesp[0]
            sp.mlsp=linesp[1]
            sp.nominal=float(linesp[2])
            sp.stats=float(linesp[3])
            sp.sys=float(linesp[4])
            sp.FinalPointName="SU_"+sp.mgl+"_"+sp.mlsp+"_0_10"
            Allsp.append(sp)

    return Allsp


bd=ReadFromFiles_BkgsData("InputData_3bjet_SR6L.txt")
SigPoints=ReadFromFiles_Gtt("InputData_3bjet_SR6L_Signal.txt")

outfilename="Gtt_SR6L_1lepton_allcorr_NT.root"
houtfile=TFile(outfilename,"recreate")

###############
#Filling data
###############
FinalHistoName="hData_SR_obs_cuts"
h_data_nom=TH1F(FinalHistoName,FinalHistoName,1,0,1)
h_data_nom.SetBinContent(1,bd.data)
h_data_nom.Write()

###############
#Filling bkgs
###############
stats=bd.SM*0.1
sys=math.sqrt(math.pow(bd.SM_totuncert,2)-math.pow(stats,2))

FinalHistoName="hBkgNom_SR_obs_cuts"
h_nom=TH1F(FinalHistoName,FinalHistoName,1,0,1)
h_nom.SetBinContent(1,bd.SM)
h_nom.SetBinError(1,stats) 
h_nom.Write()

FinalHistoName="hBkgTotUncHigh_SR_obs_cuts"
h_unc_up=TH1F(FinalHistoName,FinalHistoName,1,0,1)
h_unc_up.SetBinContent(1,bd.SM+sys)
h_unc_up.Write()

FinalHistoName="hBkgTotUncLow_SR_obs_cuts"
h_unc_down=TH1F(FinalHistoName,FinalHistoName,1,0,1)
h_unc_down.SetBinContent(1,bd.SM-sys)
h_unc_down.Write()

###############
#Filling bkgs
###############
h_signom=[]
h_sigsys_up=[]
h_sigsys_down=[]
i=0
for p in range(len(SigPoints)):
    tmpHistoName = "h"+SigPoints[p].FinalPointName
    #print tmpHistoName
    FinalHistoName = tmpHistoName+"Nom_SR_obs_cuts"
    h_signom.append(TH1F(FinalHistoName,FinalHistoName,1,0,1))
    h_signom[i].SetBinContent(1,SigPoints[p].nominal)
    h_signom[i].SetBinError(1,SigPoints[p].stats)
    h_signom[i].Write()
    
    FinalHistoName = tmpHistoName+"TotUncHigh_SR_obs_cuts"
    h_sigsys_up.append(TH1F(FinalHistoName,FinalHistoName,1,0,1))
    h_sigsys_up[i].SetBinContent(1,SigPoints[p].nominal+SigPoints[p].sys)
    h_sigsys_up[i].Write()
    
    FinalHistoName = tmpHistoName+"TotUncLow_SR_obs_cuts"
    h_sigsys_down.append(TH1F(FinalHistoName,FinalHistoName,1,0,1))
    h_sigsys_down[i].SetBinContent(1,SigPoints[p].nominal-SigPoints[p].sys)
    h_sigsys_down[i].Write()

    i+=1

houtfile.Close()
