
################################################################
## In principle all you have to setup is defined in this file ##
################################################################

from configManager import configMgr
from ROOT import kBlack,kWhite,kGray,kRed,kPink,kMagenta,kViolet,kBlue,kAzure,kCyan,kTeal,kGreen,kSpring,kYellow,kOrange
from configWriter import TopLevelXML,Measurement,ChannelXML,Sample
from systematic import Systematic
import sys


## First define HistFactory attributes
SignalRegion=sys.argv[len(sys.argv)-1]
if SignalRegion!="SR6L" and SignalRegion!="SR6T":
    print 'Wrong SignalRegion!',SignalRegion
    sys.exit()
    
gridname="Gtt"
configMgr.analysisName =  gridname+"_"+SignalRegion+"_1lepton_allcorr_NT"

configMgr.outputFileName = "results/" + configMgr.analysisName + "_AnalysisOutput.root"
   
## Scaling calculated by outputLumi / inputLumi
configMgr.inputLumi = 4.7  # Luminosity of input TTree after weighting
configMgr.outputLumi = 4.7 # Luminosity required for output histograms
configMgr.setLumiUnits("fb-1")

## setting the parameters of the hypothesis test
#configMgr.nTOYs=1000
configMgr.calculatorType=2 # 2=asymptotic calculator, 0=frequentist calculator
configMgr.testStatType=3 # 3=one-sided profile likelihood test statistic (LHC default)
configMgr.nPoints=20 # number of values scanned of signal-strength for upper-limit determination of signal strength.

configMgr.inputFileNames = ["data/" + configMgr.analysisName + ".root"]
print "conf.inputFileNames = " + configMgr.inputFileNames[0]


## Map regions to cut strings
configMgr.cutsDict["SR"] = "1.0" #This is to read the appropriate string from the histogram input file

## Defining the systematics to be applied (not applied here, yet!)
totunc  = Systematic("TotUnc","","","","","overallSys")

## List of samples and their plotting colours. Associate dedicated systematics if applicable.
bkgSample = Sample("Bkg",kBlue)
bkgSample.setStatConfig(True)
#bkgSample.addSystematic(totunc) #The totunc systematics are added to the background only
bkgSample.setNormByTheory()

dataSample = Sample("Data",kBlack)
dataSample.setData()

commonSamples = [bkgSample,dataSample]
configMgr.plotColours = [kBlue,kBlack]

## Parameters of the Measurement
measName = "BasicMeasurement"
measLumi = 1.
measLumiError = 0.039

## Parameters of Channels
cutsRegions = ["SR"]
cutsNBins = 1
cutsBinLow = 0.0
cutsBinHigh = 1.0

## Bkg-only fit 
#---------------
bkgOnly = configMgr.addTopLevelXML("SimpleChannel_BkgOnly")
bkgOnly.statErrThreshold=0.0#None #0.5
bkgOnly.addSamples(commonSamples)
bkgOnly.addSystematic(totunc) #The systematics are added globally to the fit (it means that all the samples will have these systematics associated; including signal samples)

meas = bkgOnly.addMeasurement(measName,measLumi,measLumiError)
meas.addPOI("mu_SIG")

#Add channels
#---------------
cutsChannel = bkgOnly.addChannel("cuts",cutsRegions,cutsNBins,cutsBinLow,cutsBinHigh)


#Signal
#--------
sigSamples = []

if "Gtt" in gridname:
    sigSamples = ["SU_800_300_0_10","SU_800_350_0_10","SU_800_400_0_10","SU_800_450_0_10"]


for sig in sigSamples:
    myTopLvl = configMgr.addTopLevelXMLClone(bkgOnly,"SimpleChannel_%s"%sig)

    #sigSys  = Systematic("TotUnc","","","","","overallSys")
    
    sigSample = Sample(sig,kGreen)
    sigSample.setNormFactor("mu_SIG",1,0.,100.)
    sigSample.setStatConfig(True)
    sigSample.setNormByTheory()
    #sigSample.addSystematic(sigSys)
    
    myTopLvl.addSamples(sigSample)
    myTopLvl.setSignalSample(sigSample)
